@@ -83,7 +83,11 @@ class HTML:
             self.PLOTS_PLACEHOLDER: "\n".join(self.elements),
             self.REFRESH_PLACEHOLDER: self.refresh_tag,
         }
-        return self.template.format(**kwargs)
+        for placeholder, value in kwargs.items():
+            self.template = self.template.replace(
+                "{" + placeholder + "}", value
+            )
+        return self.template
 
 
 def render_html(
@@ -109,7 +113,7 @@ def render_html(
 
     for renderer in renderers:
         document.with_scripts(renderer.SCRIPTS)
-        document.with_element(renderer.generate_html())
+        document.with_element(renderer.generate_html(html_path=output_path))
 
     output_path.write_text(document.embed(), encoding="utf8")
 
